@@ -43,6 +43,9 @@
 /* Get getline, ssize_t. */
 #include "getline.h"
 
+/* Get getsubopt. */
+#include "getsubopt.h"
+
 /* Get prototypes. */
 #include "shisa.h"
 
@@ -135,8 +138,6 @@ struct Shisa
   size_t ndbs;
 };
 
-extern int getsubopt (char **optionp, char *const *tokens, char **valuep);
-
 /* Return structure with function pointers implementing a Shisa
    backend, given a name (e.g., "file"). */
 extern _Shisa_backend *_shisa_find_backend (const char *name);
