@@ -1,5 +1,5 @@
 /* diskio.c --- Read and write data structures from disk.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -22,6 +22,7 @@
 #include <libtasn1.h>
 #define _SHISHI_HAS_LIBTASN1_H 1
 #include "internal.h"
+#include "diskio.h"
 
 #define HEADERBEG "-----BEGIN SHISHI %s-----"
 #define HEADEREND "-----END SHISHI %s-----"
@@ -35,7 +36,9 @@
 int
 _shishi_print_armored_data (Shishi * handle,
 			    FILE * fh,
-			    Shishi_asn1 asn1, char *asn1type, char *headers)
+			    Shishi_asn1 asn1,
+			    const char *asn1type,
+			    char *headers)
 {
   char *der;
   size_t derlen;
@@ -62,7 +65,7 @@ _shishi_print_armored_data (Shishi * handle,
 
   if (headers)
     {
-      fprintf (fh, headers);
+      fprintf (fh, "%s", headers);
       fprintf (fh, "\n");
     }
 
@@ -82,7 +85,7 @@ _shishi_print_armored_data (Shishi * handle,
 
 int
 _shishi_save_data (Shishi * handle, FILE * fh, Shishi_asn1 asn1,
-		   char *asn1type)
+		   const char *asn1type)
 {
   char *der;
   size_t derlen;
@@ -146,7 +149,8 @@ shishi_encticketpart_print (Shishi * handle, FILE * fh,
 
 static int
 _shishi_read_armored_data (Shishi * handle,
-			   FILE * fh, char *buffer, size_t len, char *tag)
+			   FILE * fh, char *buffer, size_t len,
+			   const char *tag)
 {
   int lno = 0;
   size_t maxsize = len;
@@ -169,7 +173,7 @@ _shishi_read_armored_data (Shishi * handle,
 	  continue;
 	}
       line[strlen (line) - 1] = '\0';
-      if (VERBOSENOICE (handle))
+      if (VERBOSENOISE (handle))
 	printf ("line %d read %d bytes: %s\n", lno, strlen (line), line);
 
       /* XXX check if all chars in line are b64 data, otherwise bail out */
@@ -817,7 +821,7 @@ shishi_key_parse (Shishi * handle, FILE * fh, Shishi_key ** key)
 	  continue;
 	}
       line[strlen (line) - 1] = '\0';
-      if (VERBOSENOICE (handle))
+      if (VERBOSENOISE (handle))
 	printf ("line %d read %d bytes: %s\n", lno, strlen (line), line);
 
       if (!in_key)
@@ -929,7 +933,7 @@ shishi_key_print (Shishi * handle, FILE * fh, Shishi_key * key)
     fprintf (fh, "\n");
 
 #if 0
-  if (VERBOSENOICE (handle))
+  if (VERBOSENOISE (handle))
     {
       for (i = 0; i < shishi_key_length (key); i++)
 	fprintf (stdout, "%02x", shishi_key_value (key)[i] & 0xFF);
