@@ -1,5 +1,5 @@
 /* encapreppart.c --- Encrypted authentication reply part functions.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -41,6 +41,7 @@ shishi_encapreppart (Shishi * handle)
   Shishi_asn1 node = NULL;
   struct timeval tv;
   struct timezone tz;
+  uint32_t seqnr;
 
   node = shishi_asn1_encapreppart (handle);
   if (!node)
@@ -52,8 +53,7 @@ shishi_encapreppart (Shishi * handle)
     goto error;
 
   gettimeofday (&tv, &tz);
-  res = shishi_asn1_write_integer (handle, node, "cusec",
-				   tv.tv_usec % 1000000);
+  res = shishi_encapreppart_cusec_set (handle, node, tv.tv_usec % 1000000);
   if (res != SHISHI_OK)
     goto error;
 
@@ -61,7 +61,28 @@ shishi_encapreppart (Shishi * handle)
   if (res != SHISHI_OK)
     goto error;
 
-  res = shishi_asn1_write (handle, node, "seq-number", NULL, 0);
+  /*
+   * For sequence numbers to adequately support the detection of
+   * replays they SHOULD be non-repeating, even across connection
+   * boundaries. The initial sequence number SHOULD be random and
+   * uniformly distributed across the full space of possible sequence
+   * numbers, so that it cannot be guessed by an attacker and so that
+   * it and the successive sequence numbers do not repeat other
+   * sequences.
+   */
+  shishi_randomize (handle, 0, &seqnr, sizeof(seqnr));
+
+  /*
+   * Implementation note: as noted before, some implementations omit
+   * the optional sequence number when its value would be zero.
+   * Implementations MAY accept an omitted sequence number when
+   * expecting a value of zero, and SHOULD NOT transmit an
+   * Authenticator with a initial sequence number of zero.
+   */
+  if (seqnr == 0)
+    seqnr++;
+
+  res = shishi_encapreppart_seqnumber_set (handle, node, seqnr);
   if (res != SHISHI_OK)
     goto error;
 
@@ -122,7 +143,7 @@ shishi_encapreppart_save (Shishi * handle, FILE * fh,
  **/
 int
 shishi_encapreppart_to_file (Shishi * handle, Shishi_asn1 encapreppart,
-			     int filetype, char *filename)
+			     int filetype, const char *filename)
 {
   FILE *fh;
   int res;
@@ -204,7 +225,7 @@ shishi_encapreppart_read (Shishi * handle, FILE * fh,
  **/
 int
 shishi_encapreppart_from_file (Shishi * handle, Shishi_asn1 * encapreppart,
-			       int filetype, char *filename)
+			       int filetype, const char *filename)
 {
   int res;
   FILE *fh;
@@ -276,7 +297,7 @@ shishi_encapreppart_get_key (Shishi * handle,
  * shishi_encapreppart_ctime:
  * @handle: shishi handle as allocated by shishi_init().
  * @encapreppart: EncAPRepPart as allocated by shishi_encapreppart().
- * @ctime: newly allocated zero-terminated character array with client time.
+ * @t: newly allocated zero-terminated character array with client time.
  *
  * Extract client time from EncAPRepPart.
  *
@@ -284,16 +305,17 @@ shishi_encapreppart_get_key (Shishi * handle,
  **/
 int
 shishi_encapreppart_ctime (Shishi * handle,
-			   Shishi_asn1 encapreppart, char **ctime)
+			   Shishi_asn1 encapreppart,
+			   char **t)
 {
-  return shishi_time (handle, encapreppart, "ctime", ctime);
+  return shishi_time (handle, encapreppart, "ctime", t);
 }
 
 /**
  * shishi_encapreppart_ctime_set:
  * @handle: shishi handle as allocated by shishi_init().
  * @encapreppart: EncAPRepPart as allocated by shishi_encapreppart().
- * @ctime: string with generalized time value to store in EncAPRepPart.
+ * @t: string with generalized time value to store in EncAPRepPart.
  *
  * Store client time in EncAPRepPart.
  *
@@ -301,12 +323,13 @@ shishi_encapreppart_ctime (Shishi * handle,
  **/
 int
 shishi_encapreppart_ctime_set (Shishi * handle,
-			       Shishi_asn1 encapreppart, char *ctime)
+			       Shishi_asn1 encapreppart,
+			       const char *t)
 {
   int res;
 
   res = shishi_asn1_write (handle, encapreppart, "ctime",
-			   ctime, GENERALIZEDTIME_TIME_LEN);
+			   t, GENERALIZEDTIME_TIME_LEN);
   if (res != SHISHI_OK)
     return res;
 
@@ -325,11 +348,12 @@ shishi_encapreppart_ctime_set (Shishi * handle,
  **/
 int
 shishi_encapreppart_cusec_get (Shishi * handle,
-			       Shishi_asn1 encapreppart, int *cusec)
+			       Shishi_asn1 encapreppart,
+			       uint32_t *cusec)
 {
   int res;
 
-  res = shishi_asn1_read_integer (handle, encapreppart, "cusec", cusec);
+  res = shishi_asn1_read_uint32 (handle, encapreppart, "cusec", cusec);
   if (res != SHISHI_OK)
     return res;
 
@@ -348,7 +372,8 @@ shishi_encapreppart_cusec_get (Shishi * handle,
  **/
 int
 shishi_encapreppart_cusec_set (Shishi * handle,
-			       Shishi_asn1 encapreppart, int cusec)
+			       Shishi_asn1 encapreppart,
+			       uint32_t cusec)
 {
   int res;
 
@@ -384,6 +409,53 @@ shishi_encapreppart_seqnumber_get (Shishi * handle,
   return res;
 }
 
+/**
+ * shishi_encapreppart_seqnumber_remove:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @encapreppart: encapreppart as allocated by shishi_encapreppart().
+ *
+ * Remove sequence number field in EncAPRepPart.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_encapreppart_seqnumber_remove (Shishi * handle,
+				      Shishi_asn1 encapreppart)
+{
+  int res;
+
+  res = shishi_asn1_write (handle, encapreppart, "seq-number", NULL, 0);
+  if (res != SHISHI_OK)
+    return res;
+
+  return SHISHI_OK;
+}
+
+/**
+ * shishi_encapreppart_seqnumber_set:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @encapreppart: encapreppart as allocated by shishi_encapreppart().
+ * @seqnumber: integer with sequence number field to store in encapreppart.
+ *
+ * Store sequence number field in EncAPRepPart.
+ *
+ * Return value: Returns %SHISHI_OK iff successful.
+ **/
+int
+shishi_encapreppart_seqnumber_set (Shishi * handle,
+				   Shishi_asn1 encapreppart,
+				   uint32_t seqnumber)
+{
+  int res;
+
+  res = shishi_asn1_write_uint32 (handle, encapreppart,
+				  "seq-number", seqnumber);
+  if (res != SHISHI_OK)
+    return res;
+
+  return SHISHI_OK;
+}
+
 /**
  * shishi_encapreppart_time_copy:
  * @handle: shishi handle as allocated by shishi_init().
