@@ -1,5 +1,5 @@
 /* encticketpart.c	encrypted ticket part handling
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -273,13 +273,13 @@ shishi_encticketpart_cname_set (Shishi * handle,
 int
 shishi_encticketpart_transited_set (Shishi * handle,
 				    Shishi_asn1 encticketpart,
-				    int trtype,
-				    char *trdata, size_t trdatalen)
+				    int32_t trtype,
+				    const char *trdata, size_t trdatalen)
 {
   int res;
 
-  res = shishi_asn1_write_uint32 (handle, encticketpart,
-				  "transited.tr-type", trtype);
+  res = shishi_asn1_write_int32 (handle, encticketpart,
+				 "transited.tr-type", trtype);
   if (res != SHISHI_OK)
     return res;
 
@@ -354,7 +354,7 @@ time_t
 shishi_encticketpart_authctime (Shishi * handle, Shishi_asn1 encticketpart)
 {
   char authtime[GENERALIZEDTIME_TIME_LEN + 1];
-  int authtimelen;
+  size_t authtimelen;
   time_t t;
   int res;
 
