@@ -1,5 +1,5 @@
 /* kdcrep.c --- Key distribution (AS/TGS) Reply functions.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -146,7 +146,7 @@ shishi_kdcrep_save (Shishi * handle, FILE * fh, Shishi_asn1 kdcrep)
  **/
 int
 shishi_kdcrep_to_file (Shishi * handle, Shishi_asn1 kdcrep,
-		       int filetype, char *filename)
+		       int filetype, const char *filename)
 {
   FILE *fh;
   int res;
@@ -226,7 +226,7 @@ shishi_kdcrep_read (Shishi * handle, FILE * fh, Shishi_asn1 * kdcrep)
  **/
 int
 shishi_kdcrep_from_file (Shishi * handle, Shishi_asn1 * kdcrep,
-			 int filetype, char *filename)
+			 int filetype, const char *filename)
 {
   int res;
   FILE *fh;
@@ -384,7 +384,7 @@ shishi_kdcrep_get_ticket (Shishi * handle,
   char *format;
   size_t buflen;
   int res;
-  int i, n;
+  size_t i, n;
 
   /* there's GOT to be an easier way to do this */
 
@@ -506,7 +506,7 @@ shishi_kdcrep_set_ticket (Shishi * handle, Shishi_asn1 kdcrep,
   char *format;
   char *buf;
   size_t buflen;
-  int i, n;
+  size_t i, n;
 
   res = shishi_asn1_read2 (handle, ticket, "tkt-vno", &buf, &buflen);
   if (res != SHISHI_OK)
