@@ -1,5 +1,5 @@
 /* libgcrypt.c --- Shishi crypto wrappers around Libgcrypt.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -22,6 +22,7 @@
 /* Note: This file is only built if Shishi uses Libgcrypt. */
 
 #include "internal.h"
+#include "crypto.h"
 
 #include <gcrypt.h>
 
@@ -64,7 +65,7 @@ _shishi_crypto_init (Shishi * handle)
 }
 
 int
-shishi_randomize (Shishi * handle, int strong, char *data, size_t datalen)
+shishi_randomize (Shishi * handle, int strong, void *data, size_t datalen)
 {
   if (strong)
     gcry_randomize (data, datalen, GCRY_VERY_STRONG_RANDOM);
@@ -78,7 +79,7 @@ shishi_crc (Shishi * handle, const char *in, size_t inlen, char *out[4])
 {
   gcry_md_hd_t hd;
   gpg_error_t err;
-  char *p;
+  unsigned char *p;
 
   err = gcry_md_open (&hd, GCRY_MD_CRC32_RFC1510, 0);
   if (err != GPG_ERR_NO_ERROR)
@@ -114,7 +115,7 @@ shishi_md4 (Shishi * handle, const char *in, size_t inlen, char *out[16])
 {
   gcry_md_hd_t hd;
   gpg_error_t err;
-  char *p;
+  unsigned char *p;
 
   err = gcry_md_open (&hd, GCRY_MD_MD4, 0);
   if (err != GPG_ERR_NO_ERROR)
@@ -145,7 +146,7 @@ shishi_md5 (Shishi * handle, const char *in, size_t inlen, char *out[16])
 {
   gcry_md_hd_t hd;
   gpg_error_t err;
-  char *p;
+  unsigned char *p;
 
   err = gcry_md_open (&hd, GCRY_MD_MD5, 0);
   if (err != GPG_ERR_NO_ERROR)
@@ -358,15 +359,31 @@ libgcrypt_dencrypt (Shishi * handle, int algo, int flags, int mode,
 
   if (ivout)
     {
+      size_t ivdiff, ivpos = 0;
+
       *ivout = xmalloc (ivlen);
 
-      if (decryptp)
-	memcpy (*ivout, in + inlen - ivlen, ivlen);
+      if (flags & GCRY_CIPHER_CBC_CTS)
+	{
+	  /* XXX what is the output iv for CBC-CTS mode?
+	     but is this value useful at all for that mode anyway?
+	     Mostly it is DES apps that want the updated iv, so this is ok. */
+
+	  if (inlen % ivlen)
+	    ivdiff = ivlen + inlen % ivlen;
+	  else
+	    ivdiff = ivlen + ivlen;
+
+	  if (inlen >= ivdiff)
+	    ivpos = inlen - ivdiff;
+	}
       else
-	/* XXX what is the output iv for CBC-CTS mode?
-	   but is this value useful at all for that mode anyway?
-	   Mostly it is DES apps that want the updated iv, so this is ok. */
-	memcpy (*ivout, *out + inlen - ivlen, ivlen);
+	ivpos = inlen - ivlen;
+
+      if (decryptp)
+	memcpy (*ivout, in + ivpos, inlen >= ivlen ? ivlen : inlen);
+      else
+	memcpy (*ivout, *out + ivpos, inlen >= ivlen ? ivlen : inlen);
     }
 
   gcry_cipher_close (ch);
