@@ -50,12 +50,22 @@ shishi_principal_default_guess (void)
  * shishi_principal_default:
  * @handle: Shishi library handle create by shishi_init().
  *
+ * The default principal name is the name returned from
+ * getpwuid(getuid) but can be overridden by specifying the
+ * environment variable SHISHI_USER.
+ *
  * Return value: Returns the default principal name used in the
  * library.  (Not a copy of it, so don't modify or deallocate it.)
  **/
 const char *
 shishi_principal_default (Shishi * handle)
 {
+  char *envuser;
+
+  envuser = getenv ("SHISHI_USER");
+  if (envuser)
+    return envuser;
+
   if (!handle->default_principal)
     {
       char *p;
