@@ -1,5 +1,5 @@
 /* kdc.h --- Header file with common definitions for Shishid.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -117,7 +117,7 @@ extern int errno;
 #ifdef HAVE_LOCALE_H
 # include <locale.h>
 #else
-# define setlocale(Category, Locale) /* empty */
+# define setlocale(Category, Locale)	/* empty */
 #endif
 #include <gettext.h>
 #define _(String) gettext (String)
@@ -149,7 +149,7 @@ struct listenspec
   int port;
   int type;
   int sockfd;
-  char buf[BUFSIZ]; /* XXX */
+  char buf[BUFSIZ];		/* XXX */
   size_t bufpos;
   int usetls;
 #ifdef USE_STARTTLS
@@ -158,8 +158,8 @@ struct listenspec
   struct listenspec *next;
 };
 
-extern Shishi * handle;
-extern Shisa * dbh;
+extern Shishi *handle;
+extern Shisa *dbh;
 extern struct gengetopt_args_info arg;
 extern struct listenspec *listenspec;
 extern char *fatal_krberror;
@@ -176,8 +176,17 @@ extern gnutls_certificate_credentials x509cred;
 extern void kdc_loop (void);
 
 /* Interface between server.c and kdc.c. */
-extern ssize_t process (char *in, int inlen, char **out);
+extern ssize_t process (const char *in, size_t inlen, char **out);
 
 /* Interface between server.c and starttls.c. */
 extern void kdc_send1 (struct listenspec *ls);
 extern int kdc_extension (struct listenspec *ls);
+
+/* Interface between shishid.c, server.c and resume.c. */
+#ifdef USE_STARTTLS
+extern void resume_db_init (size_t nconnections);
+extern void resume_db_done (void);
+extern int resume_db_store (void *dbf, gnutls_datum key, gnutls_datum data);
+extern gnutls_datum resume_db_fetch (void *dbf, gnutls_datum key);
+extern int resume_db_delete (void *dbf, gnutls_datum key);
+#endif
