@@ -1,5 +1,5 @@
 /* authenticator.c	Shishi authenticator self tests.
- * Copyright (C) 2002, 2003  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004  Simon Josefsson
  *
  * This file is part of Shishi.
  *
@@ -55,9 +55,12 @@ test (Shishi * handle)
   char buffer[BUFSIZ];
   char buffer2[BUFSIZ];
   char *p;
-  int n, m, res;
+  int res;
+  size_t n, m;
+  int32_t t;
+  uint32_t s;
 
-  /* shishi_authenticator() */
+  /* shishi_authenticator */
   a = shishi_authenticator (handle);
   if (debug)
     printf ("shishi_authenticator () => `%p'.\n", a);
@@ -66,27 +69,58 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator() failed\n");
 
+  if (debug)
+    shishi_authenticator_print (handle, stdout, a);
+
   res = shishi_authenticator_remove_subkey (handle, a);
   if (res == SHISHI_OK)
     success ("shishi_authenticator_remove_subkey() OK\n");
   else
     fail ("shishi_authenticator_remove_subkey() failed\n");
 
-  /* shishi_authenticator_set_crealm() */
+  /* shishi_authenticator_seqnumber_get */
+  res = shishi_authenticator_seqnumber_get (handle, a, &s);
+  if (res == SHISHI_OK)
+    success ("shishi_authenticator_seqnumber_get() OK\n");
+  else
+    fail ("shishi_authenticator_seqnumber_get() failed\n");
+
+  /* shishi_authenticator_seqnumber_set */
+  res = shishi_authenticator_seqnumber_set (handle, a, 42);
+  if (res == SHISHI_OK)
+    success ("shishi_authenticator_seqnumber_set() OK\n");
+  else
+    fail ("shishi_authenticator_seqnumber_set() failed\n");
+
+  /* shishi_authenticator_seqnumber_get */
+  res = shishi_authenticator_seqnumber_get (handle, a, &s);
+  if (res == SHISHI_OK && s == 42)
+    success ("shishi_authenticator_seqnumber_get() OK\n");
+  else
+    fail ("shishi_authenticator_seqnumber_get() failed\n");
+
+  /* shishi_authenticator_seqnumber_remove */
+  res = shishi_authenticator_seqnumber_remove (handle, a);
+  if (res == SHISHI_OK)
+    success ("shishi_authenticator_seqnumber_remove() OK\n");
+  else
+    fail ("shishi_authenticator_seqnumber_remove() failed\n");
+
+  /* shishi_authenticator_set_crealm */
   res = shishi_authenticator_set_crealm (handle, a, "foo");
   if (res == SHISHI_OK)
     success ("shishi_authenticator_set_crealm() OK\n");
   else
     fail ("shishi_authenticator_set_crealm() failed\n");
 
-  /* shishi_authenticator_client_set() */
+  /* shishi_authenticator_client_set */
   res = shishi_authenticator_client_set (handle, a, "foo/bar/baz");
   if (res == SHISHI_OK)
     success ("shishi_authenticator_client_set() OK\n");
   else
     fail ("shishi_authenticator_client_set() failed\n");
 
-  /* shishi_authenticator_cname_get() */
+  /* shishi_authenticator_cname_get */
   n = sizeof (buffer);
   res = shishi_authenticator_cname_get (handle, a, buffer, &n);
   if (debug)
@@ -97,14 +131,14 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_cname_get() failed\n");
 
-  /* shishi_authenticator_client_set() */
+  /* shishi_authenticator_client_set */
   res = shishi_authenticator_client_set (handle, a, "foo");
   if (res == SHISHI_OK)
     success ("shishi_authenticator_client_set() OK\n");
   else
     fail ("shishi_authenticator_client_set() failed\n");
 
-  /* shishi_authenticator_cname_get() */
+  /* shishi_authenticator_cname_get */
   n = sizeof (buffer);
   res = shishi_authenticator_cname_get (handle, a, buffer, &n);
   if (debug)
@@ -115,14 +149,14 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_cname_get() failed\n");
 
-  /* shishi_authenticator_set_crealm() */
+  /* shishi_authenticator_set_crealm */
   res = shishi_authenticator_set_crealm (handle, a, "bar");
   if (res == SHISHI_OK)
     success ("shishi_authenticator_set_crealm() OK\n");
   else
     fail ("shishi_authenticator_set_crealm() failed\n");
 
-  /* shishi_authenticator_cnamerealm_get() */
+  /* shishi_authenticator_cnamerealm_get */
   n = sizeof (buffer);
   res = shishi_authenticator_cnamerealm_get (handle, a, buffer, &n);
   if (debug)
@@ -133,39 +167,39 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_cnamerealm_get() failed\n");
 
-  /* shishi_authenticator_add_authorizationdata() */
+  /* shishi_authenticator_add_authorizationdata */
   res = shishi_authenticator_add_authorizationdata (handle, a, 42, "baz", 3);
   if (res == SHISHI_OK)
     success ("shishi_authenticator_add_authorizationdata() OK\n");
   else
     fail ("shishi_authenticator_add_authorizationdata() failed\n");
 
-  /* shishi_authenticator_authorizationdata() */
+  /* shishi_authenticator_authorizationdata */
   m = sizeof (buffer);
-  res = shishi_authenticator_authorizationdata (handle, a, &n, buffer, &m, 1);
+  res = shishi_authenticator_authorizationdata (handle, a, &t, buffer, &m, 1);
   if (debug)
     escapeprint (buffer, m);
-  if (res == SHISHI_OK && n == 42 && m == 3 && memcmp (buffer, "baz", 3) == 0)
+  if (res == SHISHI_OK && t == 42 && m == 3 && memcmp (buffer, "baz", 3) == 0)
     success ("shishi_authenticator_authorizationdata() OK\n");
   else
     fail ("shishi_authenticator_authorizationdata() failed\n");
 
-  /* shishi_authenticator_authorizationdata() */
+  /* shishi_authenticator_authorizationdata */
   m = sizeof (buffer);
-  res = shishi_authenticator_authorizationdata (handle, a, &n, buffer, &m, 2);
+  res = shishi_authenticator_authorizationdata (handle, a, &t, buffer, &m, 2);
   if (res == SHISHI_OUT_OF_RANGE)
     success ("shishi_authenticator_authorizationdata() OK\n");
   else
     fail ("shishi_authenticator_authorizationdata() failed\n");
 
-  /* shishi_authenticator_remove_cksum() */
+  /* shishi_authenticator_remove_cksum */
   res = shishi_authenticator_remove_cksum (handle, a);
   if (res == SHISHI_OK)
     success ("shishi_authenticator_remove_cksum() OK\n");
   else
     fail ("shishi_authenticator_remove_cksum() failed\n");
 
-  /* shishi_a2d() */
+  /* shishi_a2d */
   n = sizeof (buffer);
   res = shishi_a2d (handle, a, buffer, &n);
   if (res == SHISHI_OK)
@@ -173,7 +207,7 @@ test (Shishi * handle)
   else
     n = 0, fail ("shishi_a2d() failed\n");
 
-  /* shishi_authenticator_to_file() */
+  /* shishi_authenticator_to_file */
   res = shishi_authenticator_to_file (handle, a, SHISHI_FILETYPE_TEXT,
 				      "authenticator.tmp");
   if (res == SHISHI_OK)
@@ -181,13 +215,13 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_to_file() failed\n");
 
-  /* shishi_asn1_done() */
+  /* shishi_asn1_done */
   shishi_asn1_done (handle, a);
   success ("shishi_asn1_done() OK\n");
 
   a = NULL;
 
-  /* shishi_authenticator_from_file() */
+  /* shishi_authenticator_from_file */
   res = shishi_authenticator_from_file (handle, &a, SHISHI_FILETYPE_TEXT,
 					"authenticator.tmp");
   if (res == SHISHI_OK)
@@ -197,7 +231,7 @@ test (Shishi * handle)
 
   if (debug)
     {
-      /* shishi_authenticator_print() */
+      /* shishi_authenticator_print */
       res = shishi_authenticator_print (handle, stdout, a);
       if (res == SHISHI_OK)
 	success ("shishi_authenticator_print() OK\n");
@@ -205,7 +239,7 @@ test (Shishi * handle)
 	fail ("shishi_authenticator_print() failed\n");
     }
 
-  /* shishi_a2d() */
+  /* shishi_a2d */
   m = sizeof (buffer2);
   res = shishi_a2d (handle, a, buffer2, &m);
   if (res == SHISHI_OK)
@@ -219,30 +253,30 @@ test (Shishi * handle)
   else
     fail ("DER comparison failed\n");
 
-  /* shishi_authenticator_cusec_set() */
+  /* shishi_authenticator_cusec_set */
   res = shishi_authenticator_cusec_set (handle, a, 4711);
   if (res == SHISHI_OK)
     success ("shishi_authenticator_cusec_set() OK\n");
   else
     fail ("shishi_authenticator_cusec_set() failed\n");
 
-  /* shishi_authenticator_cusec_get() */
-  res = shishi_authenticator_cusec_get (handle, a, &n);
+  /* shishi_authenticator_cusec_get */
+  res = shishi_authenticator_cusec_get (handle, a, &s);
   if (debug)
-    printf ("shishi_authenticator_cusec_get () => `%d'.\n", n);
-  if (res == SHISHI_OK && n == 4711)
+    printf ("shishi_authenticator_cusec_get () => `%d'.\n", t);
+  if (res == SHISHI_OK && s == 4711)
     success ("shishi_authenticator_cusec_get() OK\n");
   else
     fail ("shishi_authenticator_cusec_get() failed\n");
 
-  /* shishi_authenticator_ctime_set() */
+  /* shishi_authenticator_ctime_set */
   res = shishi_authenticator_ctime_set (handle, a, "19700101011831Z");
   if (res == SHISHI_OK)
     success ("shishi_authenticator_ctime_set() OK\n");
   else
     fail ("shishi_authenticator_ctime_set() failed\n");
 
-  /* shishi_authenticator_ctime() */
+  /* shishi_authenticator_ctime */
   res = shishi_authenticator_ctime (handle, a, &p);
   if (debug)
     escapeprint (p, strlen (p));
@@ -251,7 +285,7 @@ test (Shishi * handle)
   else
     fail ("shishi_authenticator_ctime() failed\n");
 
-  /* shishi_a2d() */
+  /* shishi_a2d */
   n = sizeof (buffer);
   res = shishi_a2d (handle, a, buffer, &n);
   if (res == SHISHI_OK)
@@ -272,14 +306,14 @@ test (Shishi * handle)
   else
     fail ("DER comparison failed\n");
 
-  /* shishi_authenticator_clear_authorizationdata() */
+  /* shishi_authenticator_clear_authorizationdata */
   res = shishi_authenticator_clear_authorizationdata (handle, a);
   if (res == SHISHI_OK)
     success ("shishi_authenticator_clear_authorizationdata() OK\n");
   else
     fail ("shishi_authenticator_clear_authorizationdata() failed\n");
 
-  /* shishi_a2d() */
+  /* shishi_a2d */
   n = sizeof (buffer);
   res = shishi_a2d (handle, a, buffer, &n);
   if (res == SHISHI_OK)
@@ -300,7 +334,7 @@ test (Shishi * handle)
   else
     fail ("DER comparison failed\n");
 
-  /* unlink() */
+  /* unlink */
   res = unlink ("authenticator.tmp");
   if (res == 0)
     success ("unlink() OK\n");
